@@ -6,6 +6,9 @@ from pydantic import BaseModel
 class Token(BaseModel):
     access_token: str
     token_type: str
+    username: str
+    email: str
+    scopes: Optional[List]
 
 
 class TokenData(BaseModel):
